pydevDAG._attributes._metaclasses module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »

# pydevDAG._attributes._metaclasses module

## pydevDAG._metaclasses

Metaclasses for graph attributes.

class `pydevDAG._attributes._metaclasses.` `AttributeValue`

  Bases: `object`

  Abstract class that represents some attribute constant.

class `pydevDAG._attributes._metaclasses.` `AttributeValues`

  Bases: `object`

  Some set of values for a graph attribute.

  classmethod `get_value`(name)

    Return the object corresponding to `name`.

    Returns: | the type object that matches `name` or None
    Return type: | NodeType or NoneType

  classmethod `values`()

    Return a list of the values in the class.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »